// src/index.ts
import argon from "argon2-browser";
import randomBytes from "randombytes";
import { Chacha20 } from "ts-chacha20";
async function argon2({ password, salt }) {
  const result = await argon.hash({
    pass: password,
    salt,
    hashLen: 32,
    time: 2,
    mem: 32,
    parallelism: 1,
    type: argon.ArgonType.Argon2d
  });
  return Buffer.from(result.hash);
}
function generateRandom(length = 16) {
  return Uint8Array.from(randomBytes(length));
}
async function encrypt(data, password) {
  const salt = generateRandom(12);
  const key = await argon2({ password, salt });
  const encrypt2 = new Chacha20(key, salt).encrypt(
    Buffer.from(data, "utf8")
  );
  const packaged = Buffer.from([...salt, ...encrypt2]);
  return packaged.toString("base64");
}
async function decrypt(data, password) {
  const unpackaged = Buffer.from(data, "base64");
  const salt = unpackaged.subarray(0, 12);
  const input = unpackaged.subarray(12, data.length);
  const key = await argon2({ password, salt });
  const message = new Chacha20(key, salt).decrypt(input);
  return Buffer.from(message).toString("utf8");
}
export {
  argon2,
  decrypt,
  encrypt
};
